@@ -1,7 +1,6 @@
 from cst_geometry.geometry import Wire, Geometry
 from cst_geometry import simple_geometries
-from cst_geometry._script import Script
 
 
-__all__ = ["Wire", "Geometry", 'simple_geometries', 'Script']
+__all__ = ["Wire", "Geometry", 'simple_geometries']
 __version__ = 0.1
